Learn R Programming

flowPlots (version 1.20.0)

adultsNeonates: The adultsNeonates example data set of "stacked" data.

Description

The adultsNeonates data is an example of stacked data from an ICS Flow Cytometry assay.

Usage

data(adultsNeonates)

Arguments

Value

data describing the percentage in a given row.

References

TR Kollmann, J Crabtree, A Rein-Weston, D Blimkie, F Thomai, X Wang, J Furlong, E Fortuno III, A Hajjar, N Hawkins, S Self, and C Wilson, The neonatal innate immune system is not less responsive than the adult but responds differently, 2009, J Immunology, 183, 7150-7160

See Also

StackedData

Examples

Run this code
# Load adultsNeoates data
data(adultsNeonates)

Run the code above in your browser using DataLab